Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
/Users/eugene/Development/legion-utils/legion_utils/__init__.py | 8 | 0 | 0 | 0 | 0 | 100%
/Users/eugene/Development/legion-utils/legion_utils/checkin_pb2.py | 16 | 16 | 0 | 2 | 0 | 0%
/Users/eugene/Development/legion-utils/legion_utils/checkin_pb2_grpc.py | 19 | 19 | 0 | 2 | 0 | 0%
/Users/eugene/Development/legion-utils/legion_utils/core.py | 194 | 88 | 0 | 126 | 5 | 55%
/Users/eugene/Development/legion-utils/legion_utils/instrumentation.py | 121 | 40 | 2 | 42 | 3 | 66%
/Users/eugene/Development/legion-utils/legion_utils/princeps.py | 95 | 95 | 0 | 42 | 0 | 0%
/Users/eugene/Development/legion-utils/legion_utils/utils.py | 32 | 32 | 0 | 14 | 0 | 0%
Total | 485 | 290 | 2 | 228 | 8 | 41%

No items found using the specified filter.